# remirepo spec file for php-pdlib
#
# Copyright (c) 2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix  %{scl_prefix}
%scl_package        php-pdlib
%else
%global pkg_name    %{name}
%endif

%global gh_commit   1153e3e2eb28db09ed207a904096d8d6deb693a1
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    goodspb
%global gh_project  pdlib
#global gh_date     20200620
%global pecl_name   pdlib
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini

%if ! 0%{?dtsversion}
%if 0%{?rhel} == 6
%global dtsenable export PHP_AUTOCONF=autoconf268;export PHP_AUTOHEADER=autoheader268;source /opt/rh/devtoolset-7/enable
BuildRequires: devtoolset-7-toolchain
BuildRequires: autoconf268
%endif
%if 0%{?rhel} == 7
%global dtsenable source /opt/rh/devtoolset-7/enable
BuildRequires: devtoolset-7-toolchain
%endif
%endif

Summary:       A PHP extension for Dlib
Name:          %{?sub_prefix}php-%{pecl_name}
Version:       1.0.2
%if 0%{?gh_date:1}
Release:       2%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:       5%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif
License:       MIT
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

Patch0:        https://patch-diff.githubusercontent.com/raw/goodspb/pdlib/pull/37.patch

BuildRequires: %{?scl_prefix}php-devel > 7
BuildRequires: dlib-devel >= 19.21

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-%{pecl_name} <= %{version}
Obsoletes:     php72w-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:     php73-%{pecl_name} <= %{version}
Obsoletes:     php73w-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-%{pecl_name} <= %{version}
Obsoletes:     php74w-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
PDlib - A PHP extension for Dlib.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{gh_project}-%{gh_commit} NTS

cd NTS
%patch0 -p1 -b .pr

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_PDLIB_VERSION/{s/.* "//;s/".*$//;p}' php_pdlib.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   #exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
    --with-libdir=%{_lib} \
    --with-pdlib
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
    --with-libdir=%{_lib} \
    --with-pdlib
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
export NO_INTERACTION=1
export SKIP_ONLINE_TESTS=1
export REPORT_EXIT_STATUS=1

cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php --show-diff || : ignore

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php --show-diff
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE
%doc NTS/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.0.2-5
- rebuild for PHP 8.0.0RC1
- add patch for PHP 8.0.0rc1 from
  https://github.com/goodspb/pdlib/pull/37

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.0.2-4
- rebuild for PHP 8.0.0beta3

* Sun Aug  9 2020 Remi Collet <remi@remirepo.net> - 1.0.2-3
- rebuild against dlib 19.21

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 1.0.2-2
- rebuild for 8.0.0beta1

* Mon Aug  3 2020 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Mon Jul  6 2020 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- drop patches merged upstream

* Mon Jun 22 2020 Remi Collet <remi@remirepo.net> - 1.0-1.20200620git45c0b74
- new package
- open https://github.com/goodspb/pdlib/pull/25 fix linker command
- open https://github.com/goodspb/pdlib/pull/26 fix skip test
- open https://github.com/goodspb/pdlib/pull/27 display version
- open https://github.com/goodspb/pdlib/pull/29 fix build
